@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.c
- * Version    : $Id: libipv6addr.c,v 1.41 2011/09/16 18:05:13 peter Exp $
+ * Version    : $Id: libipv6addr.c,v 1.43 2011/11/27 15:44:41 peter Exp $
  * Copyright  : 2001-2011 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -227,6 +227,7 @@ void ipv6addr_clearall(ipv6calc_ipv6addr *ipv6addrp) {
 	ipv6addrp->flag_prefixuse = 0;
 	ipv6addrp->prefixlength = 0;
 	ipv6addrp->flag_valid = 0;
+	ipv6addrp->flag_scopeid = 0;
 	
 	return;
 };
@@ -513,6 +514,76 @@ int libipv6addr_get_registry_string(const ipv6calc_ipv6addr *ipv6addrp, char *re
 #undef DEBUG_function_name
 
 
+/*
+ * function stores an IPv6 literal address string into a structure
+ *
+ * in : *addrstring = IPv6 address
+ * out: *resultstring = error message
+ * out: ipv6addrp = changed IPv6 address structure
+ * ret: ==0: ok, !=0: error
+ */
+#define DEBUG_function_name "libipv6addr/addrliteral_to_ipv6addrstruct"
+int addrliteral_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp) {
+	int retval = 1, i;
+	char tempstring[NI_MAXHOST], tempstring2[NI_MAXHOST], *cptr;
+	const char *literalstring = ".ipv6-literal.net";
+
+	resultstring[0] = '\0'; /* clear result string */
+
+	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+		fprintf(stderr, "%s: Got input '%s'\n", DEBUG_function_name, addrstring);
+	};
+
+	/* lowercase string */
+	for (i = 0; i <= strlen(addrstring); i++) {
+		/* including trailing \0 */
+		tempstring2[i] = tolower(addrstring[i]);
+	}
+
+	/* search for literal string */
+	cptr = strstr(tempstring2, literalstring);
+
+	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+		fprintf(stderr, "%s: String lengths addrstring=%d strstr=%d literal=%d\n", DEBUG_function_name, strlen(addrstring), strlen(cptr), strlen(literalstring));
+	};
+
+	if (cptr == NULL) {
+		snprintf(resultstring, NI_MAXHOST - 1, "Error in given IPv6 literal address, has no 'ipv6-literal.net' included!");
+		return (1);
+	};
+
+	if (strlen(cptr) != strlen(literalstring)) {
+		snprintf(resultstring, NI_MAXHOST - 1, "Error in given IPv6 literal address, ends not with 'ipv6-literal.net'!");
+		return (1);
+	};
+
+	/* copy without literal */
+	strncpy(tempstring, addrstring, strlen(addrstring) - strlen(literalstring));
+
+	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+		fprintf(stderr, "%s: String without literal suffix: %s\n", DEBUG_function_name, tempstring);
+	};
+
+	/* replace - with : */
+	for (i = 0; i < strlen(tempstring); i++) {
+		if (tempstring[i] == '-') {
+			tempstring[i] = ':';
+		} else if (tempstring[i] == 's') {
+			tempstring[i] = '%';
+		};
+	};
+
+	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+		fprintf(stderr, "%s: String converted to non-literal format: %s\n", DEBUG_function_name, tempstring);
+	};
+
+	/* call normal IPv6 parsing function */
+	retval = addr_to_ipv6addrstruct(tempstring, resultstring, ipv6addrp);
+
+	return (retval);
+};
+#undef DEBUG_function_name
+
 /*
  * function stores an IPv6 address string into a structure
  *
@@ -524,7 +595,7 @@ int libipv6addr_get_registry_string(const ipv6calc_ipv6addr *ipv6addrp, char *re
 #define DEBUG_function_name "libipv6addr/addr_to_ipv6addrstruct"
 int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp) {
 	int retval = 1, result, i, cpoints = 0, ccolons = 0, cxdigits = 0;
-	char *addronlystring, *cp, tempstring[NI_MAXHOST], *cptr, **ptrptr;
+	char *addronlystring, *cp, tempstring[NI_MAXHOST], tempstring2[NI_MAXHOST], *cptr, **ptrptr;
 	int expecteditems = 0;
 	int temp[8];
 	unsigned int compat[4];
@@ -538,28 +609,18 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_
 		fprintf(stderr, "%s: Got input '%s'\n", DEBUG_function_name, addrstring);
 	};
 
-	if ((strlen(addrstring) < 2) || (strlen(addrstring) > 49)) {
-		/* min: :: */
-		/* max: ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff/128 */
-		/* max: ffff:ffff:ffff:ffff:ffff:ffff:123.123.123.123/128 */
-		snprintf(resultstring, NI_MAXHOST - 1, "Error in given IPv6 address, has not 2 to 49 chars!");
-		return (1);
-	};
-
 	if (strlen(addrstring) > sizeof(tempstring) - 1) {
 		fprintf(stderr, "Input too long: %s\n", addrstring);
 		return (1);
 	};
 
-	snprintf(tempstring, sizeof(tempstring) - 1, "%s", addrstring);
-	
 	ipv6addr_clearall(ipv6addrp);
 
+	snprintf(tempstring, sizeof(tempstring) - 1, "%s", addrstring);
+	
 	/* save prefix length first, if available */
-	ipv6addrp->flag_prefixuse = 0; /* reset flag first */
-
 	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
-		fprintf(stderr, "%s: Call strtok_r\n", DEBUG_function_name);
+		fprintf(stderr, "%s: Call strtok_r, searching for / in %s\n", DEBUG_function_name, tempstring);
 	};
 
 	addronlystring = strtok_r(tempstring, "/", ptrptr);
@@ -590,6 +651,43 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_
 		};
 	};
 
+	snprintf(tempstring2, sizeof(tempstring2) - 1, "%s", addronlystring);
+
+	/* save scope ID, if available */
+	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+		fprintf(stderr, "%s: Call strtok_r, searching for %% in %s\n", DEBUG_function_name, tempstring2);
+	};
+
+	addronlystring = strtok_r(tempstring2, "%%", ptrptr);
+	
+	if ( addronlystring == NULL ) {
+		fprintf(stderr, "Strange input: %s\n", addronlystring);
+		return (1);
+	};
+
+	if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+		fprintf(stderr, "%s: Got address only string: %s\n", DEBUG_function_name, addronlystring);
+	};
+
+	cp = strtok_r (NULL, "%", ptrptr);
+	if ( cp != NULL ) {
+		ipv6addrp->flag_scopeid = 1;
+		snprintf(ipv6addrp->scopeid, sizeof(ipv6addrp->scopeid) - 1, "%s", cp);
+		
+		if ( (ipv6calc_debug & DEBUG_libipv6addr) != 0 ) {
+			fprintf(stderr, "%s: scope ID    : %s\n", DEBUG_function_name, ipv6addrp->scopeid);
+			fprintf(stderr, "%s: flag_scopeid: %d\n", DEBUG_function_name, ipv6addrp->flag_scopeid);
+		};
+	};
+
+	if ((strlen(addronlystring) < 2) || (strlen(addronlystring) > 45)) {
+		/* min: :: */
+		/* max: ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff/128 */
+		/* max: ffff:ffff:ffff:ffff:ffff:ffff:123.123.123.123 */
+		snprintf(resultstring, NI_MAXHOST - 1, "Error in given IPv6 address, has not 2 to 45 chars!");
+		return (1);
+	};
+
 	/* uncompress string, if necessary */
 	if (strstr(addronlystring, "::") != NULL) {
 		result = compaddr_to_uncompaddr(addronlystring, tempstring);
@@ -743,6 +841,7 @@ int addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_
  */
 static int ipv6addrstruct_to_uncompaddr(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions) {
 	int retval = 1;
+	int i;
 	char tempstring[NI_MAXHOST];
 	
 	/* print array */
@@ -800,11 +899,30 @@ static int ipv6addrstruct_to_uncompaddr(const ipv6calc_ipv6addr *ipv6addrp, char
 		};
 	};
 
-	if (ipv6addrp->flag_prefixuse == 1) {
+	if ((ipv6addrp->flag_prefixuse == 1) && ((formatoptions & FORMATOPTION_literal) == 0)) {
 		/* append prefix length */
 		snprintf(resultstring, NI_MAXHOST - 1, "%s/%u", tempstring, (unsigned int) ipv6addrp->prefixlength);
 	} else {
-		snprintf(resultstring, NI_MAXHOST - 1, "%s", tempstring);
+		if ((formatoptions & FORMATOPTION_literal) != 0) {
+			/* replace : by - */
+			for (i =0; i < strlen(tempstring); i++) {
+				if (tempstring[i] == ':') {
+					tempstring[i] = '-';
+				};
+			};
+
+			if (ipv6addrp->flag_scopeid) {
+				snprintf(resultstring, NI_MAXHOST - 1, "%ss%s.ipv6-literal.net", tempstring, ipv6addrp->scopeid);
+			} else {
+				snprintf(resultstring, NI_MAXHOST - 1, "%s.ipv6-literal.net", tempstring);
+			}
+		} else {
+			if (ipv6addrp->flag_scopeid) {
+				snprintf(resultstring, NI_MAXHOST - 1, "%s%%%s", tempstring, ipv6addrp->scopeid);
+			} else {
+				snprintf(resultstring, NI_MAXHOST - 1, "%s", tempstring);
+			};
+		};
 	};
 
 	retval = 0;	
